@@ -110,3 +110,14 @@ class ListingResource:
 
         response = self.auth.request(endpoint, "PUT", data=json.dumps(data))
         return Inventory(**response)
+
+    
+    def get_listings_by_listing_ids(self, listing_ids: List[int], includes: str = ""):
+        params = {
+            "listing_ids":",".join(listing_ids),
+            "includes":includes
+        }
+        endpoint = "https://openapi.etsy.com/v3/application/listings/batch"
+        
+        response = self.auth.request(endpoint, params=params)
+        return Response[Listing](**response)
\ No newline at end of file
